Installation — sandman 0.7.8 documentation

### Navigation

- index
- next |
- previous |
- sandman 0.7.8 documentation »

# Installation

Simply run:

    pip install sandman

#### Previous topic

Welcome to sandman’s documentation!

#### Next topic

Using Sandman

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- next |
- previous |
- sandman 0.7.8 documentation »

© Copyright 2013, Jeff Knupp. Created using Sphinx 1.2b1.